@@ -6,7 +6,6 @@
 # alone for any other log analyzer.
 # See COPYING.TXT file about AWStats GNU General Public License.
 #-----------------------------------------------------------------------------
-# $Revision: 1.45 $ - $Author: eldy $ - $Date: 2013/01/17 19:54:15 $
 
 use strict; no strict "refs";
 #use diagnostics;
@@ -36,7 +35,7 @@ my %TmpDNSLookup = ();
 
 # ---------- Init variables --------
 use vars qw/ $REVISION $VERSION /;
-$REVISION='$Revision: 1.45 $'; $REVISION =~ /\s(.*)\s/; $REVISION=$1;
+$REVISION = '20140126';
 $VERSION="1.2 (build $REVISION)";
 
 use vars qw/ $NBOFLINESFORBENCHMARK /;
@@ -94,9 +93,11 @@ use vars qw/
 my $zcat = 'gzip -cd';
 my $zcat_file = '\.gz$';
 # For bz2 compression
-my $bzcat = 'bzcat';
+my $bzcat = 'bzip2 -cd';
 my $bzcat_file = '\.bz2$';
-
+# For xz compression
+my $xzcat = 'xz -cd';
+my $xzcat_file = '\.xz$';
 
 
 #-----------------------------------------------------------------------------
@@ -131,7 +132,7 @@ sub addDirectory {
 # Return:		None
 #------------------------------------------------------------------------------
 sub error {
-	print "Error: $_[0].\n";
+	print STDERR "Error: $_[0].\n";
     exit 1;
 }
 
@@ -160,7 +161,7 @@ sub debug {
 sub warning {
 	my $messagestring=shift;
 	if ($Debug) { debug("$messagestring",1); }
-   	print "$messagestring\n";
+   	print STDERR "$messagestring\n";
 }
 
 #-----------------------------------------------------------------------------
@@ -327,7 +328,7 @@ if (scalar @ParamFile == 0) {
 	print "$PROG allows you to get one unique output log file, sorted on date,\n";
 	print "built from particular sources:\n";
 	print " - It can read several input log files,\n";
-	print " - It can read .gz/.bz2 log files,\n";
+	print " - It can read .gz/.bz2/.xz log files,\n";
 	print " - It can also makes a fast reverse DNS lookup to replace\n";
 	print "   all IP addresses into host names in resulting log file.\n";
 	print "$PROG comes with ABSOLUTELY NO WARRANTY. It's a free software\n";
@@ -373,7 +374,7 @@ if (scalar @ParamFile == 0) {
 	print "OF DISK SPACE AT ALL) and without loading files into memory (NO NEED\n";
 	print "OF MORE MEMORY). Choose of output records is done on the fly.\n";
 	print "\n";
-	print "So logresolvemerge is particularly usefull when you want to output several\n";
+	print "So logresolvemerge is particularly useful when you want to output several\n";
 	print "and/or large log files in a fast process, with no use of disk or\n";
 	print "more memory, and in a chronological order through a pipe (to be used by a log\n";
 	print "analyzer).\n";
@@ -391,7 +392,7 @@ if (scalar @ParamFile == 0) {
 	print "\n";
 	print "Now supports/detects:\n";
 	print "  Automatic detection of log format\n";
-	print "  Files can be .gz/.bz2 files if zcat/bzcat tools are available in PATH.\n";
+	print "  Files can be .gz/.bz2/.xz files if gzip/bzip2/xz tools are available in PATH.\n";
 	print "  Multithreaded reverse DNS lookup (several parallel requests) with Perl 5.8+.\n";
 	print "New versions and FAQ at http://www.awstats.org\n";
 	exit 0;
@@ -422,7 +423,7 @@ my $timetomorrow=$tomorrowyear.$tomorrowmonth.$tomorrowday.$tomorrowhour.$tomorr
 $NBOFLINESFORBENCHMARK--;
 if ($ENV{"GATEWAY_INTERFACE"}) { $DirCgi=''; }
 if ($DirCgi && !($DirCgi =~ /\/$/) && !($DirCgi =~ /\\$/)) { $DirCgi .= '/'; }
-if (! $DirData || $DirData eq '.') { $DirData=$DIR; }	# If not defined or choosed to "." value then DirData is current dir
+if (! $DirData || $DirData eq '.') { $DirData=$DIR; }	# If not defined or chosen as "." value then DirData is current dir
 if (! $DirData)  { $DirData='.'; }						# If current dir not defined then we put it to "."
 $DirData =~ s/\/$//;
 
@@ -454,7 +455,7 @@ my $starttime=time();
 # Define the LogFileToDo list
 $cpt=1;
 foreach my $key (0..(@ParamFile-1)) {
-	if ($ParamFile[$key] !~ /\*/ && $ParamFile[$key] !~ /\?/) {
+	if (($ParamFile[$key] !~ /\*/ && $ParamFile[$key] !~ /\?/) || $ParamFile[$key] =~ /\|$/) {
 
 		if ($Debug) { debug("DBG1 Log file $ParamFile[$key] is added to LogFileToDo with number $cpt."); }
 		# Check for supported compression 
@@ -468,6 +469,11 @@ foreach my $key (0..(@ParamFile-1)) {
 			# Modify the name to include the bzcat command
 			$ParamFile[$key] = $bzcat . ' ' . $ParamFile[$key] . ' |';
 		}
+		elsif ($ParamFile[$key] =~ /$xzcat_file/) {
+			if ($Debug) { debug("XZ compression detected for Log file $ParamFile[$key]."); }
+			# Modify the name to include the xzcat command
+			$ParamFile[$key] = $xzcat . ' ' . $ParamFile[$key] . ' |';
+		}
 
 		$LogFileToDo{$cpt}=@ParamFile[$key];
 		$cpt++;
@@ -499,6 +505,11 @@ foreach my $key (0..(@ParamFile-1)) {
                     # Modify the name to include the bzcat command
                     $LogFileToDo{$cpt}=$bzcat . ' ' . "$DirFile/$filearray[$i]" . ' |';
                 }
+                elsif ($filearray[$i] =~ /$xzcat_file/) {
+                    if ($Debug) { debug("XZ compression detected for Log file $filearray[$i]."); }
+                    # Modify the name to include the xzcat command
+                    $LogFileToDo{$cpt}=$xzcat . ' ' . "$DirFile/$filearray[$i]" . ' |';
+                }
                 else {
                     $LogFileToDo{$cpt}="$DirFile/$filearray[$i]";
                 }
@@ -654,7 +665,7 @@ STOPONFIRSTEOF: while (1 == 1)
 	if(!defined($logfilechosen)) { last; }              # No more record to process 
 	
 	# Record is chosen
-	if ($Debug) { debug(" We choosed to qualify record of file number $logfilechosen",3); }
+	if ($Debug) { debug(" We chose to qualify record of file number $logfilechosen",3); }
 	if ($Debug) { debug("  Record is $linerecord{$logfilechosen}",3); }
 			
 	# Record is approved. We found a new line to parse in file number $logfilechosen
